@@ -55,17 +55,14 @@
 #include "ytime.h"
 #include "base.h"
 #include "ypointer.h"
+#include "ylocale.h"
 #include "upath.h"
 #include "intl.h"
 #define GUI_EVENT_NAMES
 #include "guievent.h"
 
-#ifdef HAVE_SYS_IOCTL_H
 #include <unistd.h>
 #include <sys/ioctl.h>
-#else
-#undef ENABLE_OSS
-#endif
 
 #ifdef HAVE_SYS_SOUNDCARD_H
 #include <sys/soundcard.h>
@@ -77,12 +74,10 @@
 #include <sndfile.h>
 #endif
 
-#ifdef HAVE_FCNTL_H
 #include <fcntl.h>
 // that's precise enough to detect a modern system
 #include <sys/types.h>
 #include <sys/stat.h>
-#endif
 
 /******************************************************************************/
 
@@ -979,10 +974,7 @@ void IceSound::playOnce(char* value) {
 }
 
 int main(int argc, char *argv[]) {
-
-    bindtextdomain(PACKAGE, LOCDIR);
-    textdomain(PACKAGE);
-
+    YLocale locale;
     ApplicationName = my_basename(argv[0]);
 
     IceSound icesound;
